@@ -3,7 +3,7 @@ use 5.006;
 use strict;
 use warnings;
 BEGIN {
-	our $VERSION = '0.05'; # VERSION
+	our $VERSION = '0.06'; # VERSION
 }
 use parent 'Exporter';
 use Test::Builder;
@@ -26,24 +26,32 @@ sub _get_version {
 sub version_ok {
 	my ( $file, $name ) = @_;
 
+	$name ||= "check version in $file";
+
+	unless ( $file and -e $file ) {
+		$test->ok( 0, $name );
+		$test->diag( "NO_FILE: $file" );
+		return 4;
+	}
+
 	my $version = _get_version( $file );
 
-	$name ||= "validate VERSION in $file";
 
-	if ( not $version ) {
+	unless ( $version ) {
 		$test->ok( 0 , $name );
-		$test->diag( "VERSION not defined in $file" );
-		return;
+		$test->diag( "NO_VERSION: $file" );
+		return 3;
 	}
 
-	if ( is_lax( $version ) ) {
-		$test->ok( 1, "VERSION $version in $file is valid" );
-	}
-	else {
+	unless ( is_lax( $version ) ) {
 		$test->ok( 0, $name );
-		$test->diag( "VERSION in $file is not a valid version" );
+		$test->diag( "NOT_VALID: $file" );
+		return 2;
 	}
-	return;
+
+	$test->ok( 1, $name );
+	$test->diag( "VERSION_OK: $file $version" );
+	return 1;
 }
 
 sub version_all_ok {
@@ -86,7 +94,7 @@ Test::Version - Check to see that version's in modules are sane
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -114,6 +122,11 @@ the C<is_lax> function in L<version>.
 Test a single C<.pm> file by passing a path to the function. Checks if the
 module has a version, and that it is valid with C<is_lax>.
 
+Returns the following diagnostics
+
+	NO_VERSION: $file           No version was found to exist in $file
+	NOT_VALID: $file $version   $version in $file is not "lax"
+
 =item C<version_all_ok( [ $directory, [ $name ]] );>
 
 Test all modules in a directory with C<version_ok>. By default it will check
